searchData={"items":[{"type":"module","title":"OctoFetch","doc":"This library allows you to download release artifacts from GitHub. By using this library\nyou get the following functionality for your GitHub downloader client:\n\n- Automatic SHA validation for downloaded artifacts (security measure to ensure that\n  users download valid copies of artifacts)\n- Automatic archive extraction for `.zip` and `.tar.gz` downloads\n- Dynamic artifact downloading based on user's platform\n- Support only specific versions of artifacts from the provided repo","ref":"OctoFetch.html"},{"type":"module","title":"Sample usage - OctoFetch","doc":"If you want to make a downloader for the Litestream binary for example, you can define\na downloader module like so:\n\n```elixir\ndefmodule LiteStream.Downloader do\n  use OctoFetch,\n    latest_version: \"0.3.9\",\n    github_repo: \"benbjohnson/litestream\",\n    download_versions: %{\n      \"0.3.9\" => [\n        {:darwin, :amd64, \"74599a34dc440c19544f533be2ef14cd4378ec1969b9b4fcfd24158946541869\"},\n        {:linux, :amd64, \"806e1cca4a2a105a36f219a4c212a220569d50a8f13f45f38ebe49e6699ab99f\"},\n        {:linux, :arm64, \"61acea9d960633f6df514972688c47fa26979fbdb5b4e81ebc42f4904394c5c5\"}\n      ],\n      \"0.3.8\" => [\n        {:darwin, :amd64, \"d359a4edd1cb98f59a1a7c787bbd0ed30c6cc3126b02deb05a0ca501ff94a46a\"},\n        {:linux, :amd64, \"530723d95a51ee180e29b8eba9fee8ddafc80a01cab7965290fb6d6fc31381b3\"},\n        {:linux, :arm64, \"1d6fb542c65b7b8bf91c8859d99f2f48b0b3251cc201341281f8f2c686dd81e2\"}\n      ]\n    }\n\n  # You must implement this function to generate the names of the downloads based on the\n  # user's current running environment\n  @impl true\n  def download_name(version, :darwin, arch), do: \"litestream-v#{version}-darwin-#{arch}.zip\"\n  def download_name(version, :linux, arch), do: \"litestream-v#{version}-linux-#{arch}.tar.gz\"\nend\n```\n\nYou would then be able to download the release artifact by doing the following:\n\n```elixir\nLitestream.Downloader.download(\".\")\n```\n\nIf you are on an ARM based Mac, the above snippet won't work since Litestream does not currently\nbuild ARM artifacts. But you can always override what OctoFetch dynamically resolves\nby doing the following:\n\n```elixir\nLitestream.Downloader.download(\".\", override_architecture: :amd64)\n```\n\nBe sure to look at the `OctoFetch.download/3` docs for supported options and\n`OctoFetch.Downloader` to see what behaviour callbacks you can override.","ref":"OctoFetch.html#module-sample-usage"},{"type":"function","title":"OctoFetch.download/3","doc":"Download the GitHub release artifact and write it to the specified location.\n\nThe supported `opts` arguments are:\n\n- `override_version`: By default, the latest version (as specified by the downloader module) will\n  be downloaded. But you can also specify any additional versions that are also supported by the\n  `:download_versions` map.\n\n- `override_operating_system`: By default, the operating system is dynamically deteremined based on\n   the what the BEAM reports. If you would like to override those results, you can pass\n   `:windows`, `:darwin`, or `:linux`.\n\n- `override_architecture`: By default, the architecture is dynamically deteremined based on\n  the what the BEAM reports. If you would like to override those results, you can pass `:amd64`\n  or `:arm64`.","ref":"OctoFetch.html#download/3"},{"type":"behaviour","title":"OctoFetch.Downloader","doc":"This module defines the callbacks that a GitHub downloader needs\nto implement in order to fetch artifacts from GitHub. `base_url/2` and\n`default_version/0` are automatically implemented for you when you use\nthe `OctoFetch` module, but you always have the option to\noverride their default implementations.","ref":"OctoFetch.Downloader.html"},{"type":"callback","title":"OctoFetch.Downloader.base_url/2","doc":"This callback generates the base URL for the artifact based on the provided GitHub repo\nand the requested version. The default implementation from `OctoFetch` is:\n\n```elixir\ndef base_url(github_repo, version) do\n  \"https://github.com/#{github_repo}/releases/download/v#{version}/\"\nend\n```","ref":"OctoFetch.Downloader.html#c:base_url/2"},{"type":"callback","title":"OctoFetch.Downloader.default_version/0","doc":"This callback returns the default version that sould be downloaded if the\nuser does not override the version. It will default to the value of `:latest_version`\nas provided to the `OctoFetch` `__using__/1` macro.","ref":"OctoFetch.Downloader.html#c:default_version/0"},{"type":"callback","title":"OctoFetch.Downloader.download/2","doc":"This callback acts as a pass through to the `OctoFetch` module for the\ndownloader implementation. See `OctoFetch.download/3` for supported `opts`.","ref":"OctoFetch.Downloader.html#c:download/2"},{"type":"callback","title":"OctoFetch.Downloader.download_name/3","doc":"This function must be implemented by your downloader module and is used to\ndynamically generate the name of the download artifact based on the user's\nrunning environment. For example, for Litestream you would do something like\nso to ensure that users download the proper artifact:\n\n```elixir\ndef download_name(version, :darwin, arch), do: \"litestream-v#{version}-darwin-#{arch}.zip\"\ndef download_name(version, :linux, arch), do: \"litestream-v#{version}-linux-#{arch}.tar.gz\"\n```","ref":"OctoFetch.Downloader.html#c:download_name/3"},{"type":"callback","title":"OctoFetch.Downloader.post_write_hook/1","doc":"This callback is invoked whenever a file is written to the filesystem as\na result from the download. This callback may be invoked several times\nif the download was an archive file and contained multiple files.","ref":"OctoFetch.Downloader.html#c:post_write_hook/1"},{"type":"callback","title":"OctoFetch.Downloader.pre_download_hook/2","doc":"This callback is invoked prior to a file being downloaded. This gives you\nthe opportunity to skip the download if you so chose by returning `:skip`. Otherwise,\nreturn `:cont` to continue with the download.","ref":"OctoFetch.Downloader.html#c:pre_download_hook/2"},{"type":"type","title":"OctoFetch.Downloader.arch/0","doc":"","ref":"OctoFetch.Downloader.html#t:arch/0"},{"type":"type","title":"OctoFetch.Downloader.download_result/0","doc":"","ref":"OctoFetch.Downloader.html#t:download_result/0"},{"type":"type","title":"OctoFetch.Downloader.os/0","doc":"","ref":"OctoFetch.Downloader.html#t:os/0"},{"type":"module","title":"OctoFetch.Test","doc":"This module contains testing utilities to validate\ndownloader modules and their implementations.","ref":"OctoFetch.Test.html"},{"type":"function","title":"OctoFetch.Test.test_all_supported_downloads/1","doc":"Go through all of the supported downloads and validate that\nthey work.","ref":"OctoFetch.Test.html#test_all_supported_downloads/1"},{"type":"function","title":"OctoFetch.Test.test_version_for_current_platform/2","doc":"Test that the specified version can be downloaded","ref":"OctoFetch.Test.html#test_version_for_current_platform/2"},{"type":"extras","title":"README","doc":"Download, verify, and extract GitHub release artifacts effortlessly right from Elixir\n \n\n \n   \n     \n   \n\n   \n     \n   \n\n   \n     \n   \n\n   \n     \n   \n \n\n \n \n\n# Contents\n\n- [Installation](#installation)\n- [Supporting OctoFetch](#supporting-octofetch)\n- [Setting Up OctoFetch](#setting-up-octofetch)\n- [Attribution](#attribution)","ref":"readme.html"},{"type":"extras","title":"Installation - README","doc":"[Available in Hex](https://hex.pm/packages/octo_fetch), the package can be installed by adding\n`octo_fetch` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:octo_fetch, \"~> 0.4.0\"}\n  ]\nend\n```\n\nDocumentation can be found at [https://hexdocs.pm/octo_fetch](https://hexdocs.pm/octo_fetch).","ref":"readme.html#installation"},{"type":"extras","title":"Supporting OctoFetch - README","doc":"If you rely on this library, it would much appreciated if you can give back to the project in order to help\nensure its continued development.\n\n#","ref":"readme.html#supporting-octofetch"},{"type":"extras","title":"Gold Sponsors - README","doc":"#","ref":"readme.html#gold-sponsors"},{"type":"extras","title":"Silver Sponsors - README","doc":"#","ref":"readme.html#silver-sponsors"},{"type":"extras","title":"Bronze Sponsors - README","doc":"","ref":"readme.html#bronze-sponsors"},{"type":"extras","title":"Setting Up OctoFetch - README","doc":"If you want to create a downloader utility for a particular GitHub repository, you can use this library\nto take care of all of the boilerplate, validation, and archive extraction. For example, if you want to create\na downloader for Litestream, you can do the following:\n\n```elixir\ndefmodule LiteStream.Downloader do\n  use OctoFetch,\n    latest_version: \"0.3.9\",\n    github_repo: \"benbjohnson/litestream\",\n    download_versions: %{\n      \"0.3.9\" => [\n        {:darwin, :amd64, \"74599a34dc440c19544f533be2ef14cd4378ec1969b9b4fcfd24158946541869\"},\n        {:linux, :amd64, \"806e1cca4a2a105a36f219a4c212a220569d50a8f13f45f38ebe49e6699ab99f\"},\n        {:linux, :arm64, \"61acea9d960633f6df514972688c47fa26979fbdb5b4e81ebc42f4904394c5c5\"}\n      ],\n      \"0.3.8\" => [\n        {:darwin, :amd64, \"d359a4edd1cb98f59a1a7c787bbd0ed30c6cc3126b02deb05a0ca501ff94a46a\"},\n        {:linux, :amd64, \"530723d95a51ee180e29b8eba9fee8ddafc80a01cab7965290fb6d6fc31381b3\"},\n        {:linux, :arm64, \"1d6fb542c65b7b8bf91c8859d99f2f48b0b3251cc201341281f8f2c686dd81e2\"}\n      ]\n    }\n\n  # You must implement this function to generate the names of the downloads based on the\n  # user's current running environment\n  @impl true\n  def download_name(version, :darwin, arch), do: \"litestream-v\\#{version}-darwin-\\#{arch}.zip\"\n  def download_name(version, :linux, arch), do: \"litestream-v\\#{version}-linux-\\#{arch}.tar.gz\"\nend\n```\n\nYou would then be able to download the release artifact by doing the following:\n\n```elixir\niex (1) > Litestream.Downloader.download(\".\")\n{:ok, [\"./litestream\"], []}\n```","ref":"readme.html#setting-up-octofetch"},{"type":"extras","title":"Attribution - README","doc":"It wouldn't be right to not include somewhere in this project a \"thank you\" to the various projects and people that\nhelped make this possible:\n\n- The logo for the project is an edited version of an SVG image from the [unDraw project](https://undraw.co/)\n- The work done in [Phoenix Tailwind](https://github.com/phoenixframework/tailwind) served as a baseline for how to\n  structure this library.","ref":"readme.html#attribution"}],"content_type":"text/markdown"}